@@ -99,15 +99,11 @@ def test_Phaser_02():
         {
             \time 4/4
             c'8
-            d'8
-            ~
-            d'8
+            d'4
             e'8
             ~
             e'8
-            f'8
-            ~
-            f'8
+            f'4
             c'8
         }
         """)
@@ -357,9 +353,7 @@ def test_Phaser_06():
             e'2
             ~
             e'4.
-            c'8
-            ~
-            c'8
+            c'4
             d'8
         }
         """)
@@ -393,9 +387,7 @@ def test_Phaser_07():
             d'2
             ~
             d'8.
-            \times 2/3 {
-                c'16.
-            }
+            c'16
             \times 2/3 {
                 d'16
                 e'8
@@ -454,7 +446,9 @@ def test_Phaser_09():
             c'8
             d'8
             ~
-            d'4.
+            d'4
+            ~
+            d'8
             c'4.
         }
         """)
@@ -484,7 +478,9 @@ def test_Phaser_09():
             c'8
             d'8
             ~
-            d'4.
+            d'4
+            ~
+            d'8
             c'4.
             ~
         }
@@ -516,7 +512,9 @@ def test_Phaser_10():
             <d' fs' a'>8
             c'8
             ~
-            c'4.
+            c'4
+            ~
+            c'8
             <d' fs' a'>4.
         }
         """)
@@ -546,7 +544,9 @@ def test_Phaser_10():
             <d' fs' a'>8
             c'8
             ~
-            c'4.
+            c'4
+            ~
+            c'8
             <d' fs' a'>4.
             ~
         }
@@ -609,12 +609,8 @@ def test_Phaser_12():
             d'8
             e'8
             c'16
-            d'16
-            ~
-            d'16
-            e'16
-            ~
-            e'16
+            d'8
+            e'8
             c'16
             d'8
             e'8
@@ -635,12 +631,8 @@ def test_Phaser_12():
             d'8
             e'8
             e'16
-            c'16
-            ~
-            c'16
-            d'16
-            ~
-            d'16
+            c'8
+            d'8
             e'16
             e'8
             c'8
@@ -760,19 +752,15 @@ def test_Phaser_16():
             c'8
             - \staccato
             \<
-            d'8
+            d'4
             \f
             - \tenuto
-            ~
-            d'8
             e'8
             \p
             - \accent
             ~
             e'8
-            f'8
-            ~
-            f'8
+            f'4
             c'8
             - \staccato
             d'4
@@ -787,19 +775,14 @@ def test_Phaser_16():
             d'8
             \f
             - \tenuto
-            e'8
+            e'4
             \p
             - \accent
-            ~
-            e'8
             f'8
             ~
             f'8
-            c'8
+            c'4
             - \staccato
-            ~
-            c'8
-            \<
             d'8
             \f
             - \tenuto
@@ -928,12 +911,8 @@ def test_Phaser_19():
             d'4
             e'4
             c'8
-            d'8
-            ~
-            d'8
-            e'8
-            ~
-            e'8
+            d'4
+            e'4
             c'8
             d'4
             e'4
@@ -1119,7 +1098,7 @@ def test_Phaser_23():
             e'2.
         }
         """)
-    auxjad.remove_repeated_time_signatures(staff)
+    auxjad.mutate(staff[:]).remove_repeated_time_signatures()
     assert format(staff) == abjad.String.normalize(
         r"""
         \new Staff
@@ -1227,10 +1206,8 @@ def test_Phaser_25():
             d'4
             ~
             d'16
-            e'16
+            e'8
             \f
-            ~
-            e'16
             f'16
             \p
             ~
@@ -1238,7 +1215,9 @@ def test_Phaser_25():
             \>
             g'16
             ~
-            g'4..
+            g'4
+            ~
+            g'8.
             a'16
             \pp
             ~
@@ -1249,8 +1228,9 @@ def test_Phaser_25():
             (
             c'4.
             \<
-            (
-            d'4.
+            d'8
+            ~
+            d'4
             e'8
             \f
             f'8
@@ -1260,18 +1240,17 @@ def test_Phaser_25():
             \>
             g'8
             ~
-            g'4.
-            a'8
-            \pp
+            g'4
             ~
-            a'8
+            g'8
+            a'4
+            \pp
             )
             c'8
             \p
             (
             c'4
             ~
-            (
             c'16
             \<
             d'8.
@@ -1301,8 +1280,9 @@ def test_Phaser_25():
             (
             c'4
             \<
-            (
-            d'4.
+            d'4
+            ~
+            d'8
             e'8
             \f
             f'4
@@ -1316,3 +1296,102 @@ def test_Phaser_25():
             \p
         }
         """)
+
+
+def test_Phaser_26():
+    container = abjad.Container(r"c'4 d'4 e'4 f'4")
+    phaser = auxjad.Phaser(container,
+                           step_size=(1, 32),
+                           )
+    notes = phaser.output_n(3, tie_identical_pitches=True)
+    staff = abjad.Staff(notes)
+    assert format(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 4/4
+            c'4
+            d'4
+            e'4
+            f'4
+            c'8..
+            d'32
+            ~
+            d'8..
+            e'32
+            ~
+            e'8..
+            f'32
+            ~
+            f'8..
+            c'32
+            ~
+            c'8.
+            d'16
+            ~
+            d'8.
+            e'16
+            ~
+            e'8.
+            f'16
+            ~
+            f'8.
+            c'16
+        }
+        """)
+
+
+def test_Phaser_27():
+    container = abjad.Container(r"c'2 d'2")
+    phaser = auxjad.Phaser(container,
+                           step_size=(1, 8),
+                           )
+    notes = phaser.output_all(tie_identical_pitches=True)
+    staff = abjad.Staff(notes)
+    assert format(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 4/4
+            c'2
+            d'2
+            c'4.
+            d'8
+            ~
+            d'4.
+            c'8
+            ~
+            c'4
+            d'2
+            c'4
+            ~
+            c'8
+            d'8
+            ~
+            d'4
+            ~
+            d'8
+            c'4.
+            d'2
+            c'2
+            d'4.
+            c'8
+            ~
+            c'4.
+            d'8
+            ~
+            d'4
+            c'2
+            d'4
+            ~
+            d'8
+            c'8
+            ~
+            c'4
+            ~
+            c'8
+            d'4.
+            c'2
+            d'2
+        }
+        """)
