@@ -145,7 +145,8 @@ def test_Shuffler_03():
 
 def test_Shuffler_04():
     container = abjad.Container(
-        r"\time 3/4 c'16 d'8. ~ d'4 e'4 r4 f'4 ~ f'8.. g'32")
+        r"\time 3/4 c'16 d'8. ~ d'4 e'4 r4 f'4 ~ f'8.. g'32"
+    )
     shuffler = auxjad.Shuffler(container)
     notes = shuffler.rotate()
     staff = abjad.Staff(notes)
@@ -196,7 +197,8 @@ def test_Shuffler_04():
         }
         """)
     container = abjad.Container(
-        r"\time 3/4 c'16 d'8. ~ d'4 e'4 r4 f'4 ~ f'8.. g'32")
+        r"\time 3/4 c'16 d'8. ~ d'4 e'4 r4 f'4 ~ f'8.. g'32"
+    )
     shuffler = auxjad.Shuffler(container, pitch_only=True)
     notes = shuffler.rotate()
     staff = abjad.Staff(notes)
@@ -344,10 +346,10 @@ def test_Shuffler_07():
             e'4.
             g'16
             f'8.
-            e'4.
-            c'8
+            e'4
             ~
-            c'8
+            e'8
+            c'4
             d'8
         }
         """)
@@ -394,9 +396,7 @@ def test_Shuffler_08():
             ~
             f'16
             g'16
-            c'8
-            ~
-            c'8
+            c'4
             d'8
         }
         """)
@@ -453,7 +453,8 @@ def test_Shuffler_09():
 def test_Shuffler_10():
     random.seed(98103)
     container = abjad.Container(
-        r"\time 3/4 c'8. d'4 r8 r8. \time 2/4 e'16 f'4..")
+        r"\time 3/4 c'8. d'4 r8 r8. \time 2/4 e'16 f'4.."
+    )
     shuffler = auxjad.Shuffler(container)
     notes = shuffler.shuffle_n(2)
     staff = abjad.Staff(notes)
@@ -518,11 +519,9 @@ def test_Shuffler_11():
             - \marcato
             ~
             f'8
-            <c' e' g'>8
+            <c' e' g'>4
             \p
             - \tenuto
-            ~
-            <c' e' g'>8
             e'8
             - \staccato
             f'4
@@ -653,7 +652,7 @@ def test_Shuffler_15():
 
 def test_Shuffler_16():
     random.seed(19867)
-    container = abjad.Container(r"c'4 d'8 e'8 f'2")
+    container = abjad.Container(r"c'4 d'8. e'16 f'2")
     shuffler = auxjad.Shuffler(container)
     notes = shuffler()
     staff = abjad.Staff(notes)
@@ -662,14 +661,16 @@ def test_Shuffler_16():
         \new Staff
         {
             \time 4/4
-            e'8
-            f'8
+            e'16
+            f'8.
             ~
-            f'4.
-            c'8
+            f'4
             ~
-            c'8
-            d'8
+            f'16
+            c'8.
+            ~
+            c'16
+            d'8.
         }
         """)
     random.seed(19867)
@@ -683,10 +684,10 @@ def test_Shuffler_16():
         \new Staff
         {
             \time 4/4
-            e'8
+            e'16
             f'2
             c'4
-            d'8
+            d'8.
         }
         """)
 
@@ -739,7 +740,7 @@ def test_Shuffler_18():
             d'4
         }
         """)
-    auxjad.remove_repeated_time_signatures(staff)
+    auxjad.mutate(staff[:]).remove_repeated_time_signatures()
     assert format(staff) == abjad.String.normalize(
         r"""
         \new Staff
@@ -794,3 +795,88 @@ def test_Shuffler_19():
     score = abjad.Score([staff1, staff2])
     with pytest.raises(ValueError):
         auxjad.Shuffler(score)
+
+
+def test_Shuffler_20():
+    random.seed(76123)
+    container = abjad.Container(r"\times 2/3 {\time 3/4 r8 d'8 r8} c'4 r4")
+    shuffler = auxjad.Shuffler(container, pitch_only=True)
+    notes = shuffler.shuffle_n(5)
+    staff = abjad.Staff(notes)
+    assert format(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \times 2/3 {
+                \time 3/4
+                r8
+                d'8
+                r8
+            }
+            r4
+            c'4
+            \times 2/3 {
+                d'8
+                c'8
+                r8
+            }
+            r4
+            r4
+            r4
+            d'4
+            c'4
+            \times 2/3 {
+                r8
+                d'8
+                c'8
+            }
+            r4
+            r4
+            \times 2/3 {
+                c'8
+                r8
+                r8
+            }
+            d'4
+            r4
+        }
+        """)
+
+
+def test_Shuffler_21():
+    random.seed(98141)
+    container = abjad.Container(r"c'4.. d'16 e'4. f'8")
+    shuffler = auxjad.Shuffler(container, pitch_only=True)
+    notes = shuffler.shuffle_n(2)
+    staff = abjad.Staff(notes)
+    shuffler.pitch_only = False
+    notes = shuffler.shuffle_n(2)
+    staff.append(notes)
+    auxjad.mutate(staff[:]).remove_repeated_time_signatures()
+    assert format(staff) == abjad.String.normalize(
+        r"""
+        \new Staff
+        {
+            \time 4/4
+            d'4..
+            c'16
+            f'4.
+            e'8
+            d'4..
+            f'16
+            c'4.
+            e'8
+            f'16
+            d'4..
+            e'8
+            c'4.
+            c'4.
+            d'8
+            ~
+            d'4
+            ~
+            d'16
+            e'8
+            f'16
+        }
+        """)
