@@ -43,7 +43,9 @@ def test_WindowLooper_01():
             c'8.
             d'16
             ~
-            d'4..
+            d'4
+            ~
+            d'8.
             e'16
             ~
             e'8.
@@ -60,7 +62,9 @@ def test_WindowLooper_01():
             c'8.
             d'16
             ~
-            d'4..
+            d'4
+            ~
+            d'8.
             e'16
             ~
             e'8.
@@ -152,9 +156,7 @@ def test_WindowLooper_03():
         {
             \time 3/4
             d'4.
-            e'8
-            ~
-            e'8
+            e'4
             r8
         }
         """)
@@ -178,9 +180,7 @@ def test_WindowLooper_03():
         {
             \time 3/4
             d'8
-            e'8
-            ~
-            e'8
+            e'4
             r4.
         }
         """)
@@ -318,7 +318,9 @@ def test_WindowLooper_06():
             c'8.
             d'16
             ~
-            d'4..
+            d'4
+            ~
+            d'8.
             e'16
             ~
             e'8.
@@ -335,10 +337,10 @@ def test_WindowLooper_06():
             c'8
             d'8
             ~
-            d'4.
-            e'8
+            d'4
             ~
-            e'8
+            d'8
+            e'4
             f'8
         }
         """)
@@ -673,7 +675,9 @@ def test_WindowLooper_18():
             c'8.
             d'16
             ~
-            d'4..
+            d'4
+            ~
+            d'8.
             e'16
             ~
             e'8.
@@ -711,7 +715,9 @@ def test_WindowLooper_19():
             \f
             - \tenuto
             ~
-            d'4..
+            d'4
+            ~
+            d'8.
             e'16
             \ppp
             - \accent
@@ -747,7 +753,9 @@ def test_WindowLooper_20():
             c'8.
             d'16
             ~
-            d'4..
+            d'4
+            ~
+            d'8.
             e'16
             ~
             e'8.
@@ -950,9 +958,7 @@ def test_WindowLooper_26():
             e'4
             \time 3/4
             d'4.
-            e'8
-            ~
-            e'8
+            e'4
             r8
             \time 3/4
             d'4
@@ -960,9 +966,7 @@ def test_WindowLooper_26():
             r4
             \time 3/4
             d'8
-            e'8
-            ~
-            e'8
+            e'4
             r4.
             \time 3/4
             e'4
@@ -973,7 +977,7 @@ def test_WindowLooper_26():
             r2
         }
         """)
-    auxjad.remove_repeated_time_signatures(staff)
+    auxjad.mutate(staff[:]).remove_repeated_time_signatures()
     assert format(staff) == abjad.String.normalize(
         r"""
         \new Staff
@@ -989,17 +993,13 @@ def test_WindowLooper_26():
             d'2
             e'4
             d'4.
-            e'8
-            ~
-            e'8
+            e'4
             r8
             d'4
             e'4
             r4
             d'8
-            e'8
-            ~
-            e'8
+            e'4
             r4.
             e'4
             r2
